@@ -117,14 +117,14 @@ providers_list = {
         r'gmanga\.me/mangas/.',
     ],
     'gomanga_co': [
-        r'gomanga\.co/reader/.',
+        # r'gomanga\.co/reader/.',
         r'jaiminisbox\.com/reader/.',
         r'kobato\.hologfx\.com/reader/.',
-        r'seinagi\.org/reader/.',
-    ],
-    'goodmanga_net': [
-        r'goodmanga\.net/.',
+        # r'seinagi\.org/reader/.',
     ],
+    # 'goodmanga_net': [
+    #     r'goodmanga\.net/.',
+    # ],
     'helveticascans_com': [
         r'helveticascans\.com/r/(series|read)/.',
     ],
@@ -306,6 +306,7 @@ providers_list = {
     ],
     'mangabat_com': [
         r'mangabat\.com/(manga|chapter)/.',
+        r'mangabat\.com/read-.',
     ],
     'mangabb_co': [
         r'mangabb\.co/.',
